Installation
=============

We highly recommend having a virtual environment to install HySOM. This will help you avoid any potential conflicts with other packages you may have installed. You can use either `venv` or `conda` to create a virtual environment. A short guide using `conda` can be found `here <conda_env_setup.html>`_

If you already have a virtual environment set up, you can proceed to install HySOM:


Using pip
----------
.. code-block:: bash

    pip install hysom  
